==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/encryption_ng/decryptor.h <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DECRYPTOR_H
#define DECRYPTOR_H

#include <QtCore/QObject>

#include "encryption_exports.h"

class Chat;
class EncryptionProvider;

class ENCRYPTIONAPI Decryptor : public QObject
{
	Q_OBJECT

	EncryptionProvider *Provider;

public:
	Decryptor(EncryptionProvider *provider, QObject *parent = 0);
	virtual ~Decryptor() {}

	EncryptionProvider * provider() { return Provider; }

	virtual QByteArray decrypt(const QByteArray &data, Chat chat, bool *ok = 0) = 0;

};

#endif // DECRYPTOR_H

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/encryption_ng/decryptor.h <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Tomasz Rostanski (rozteck@interia.pl)
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DECRYPTOR_H
#define DECRYPTOR_H

#include <QtCore/QObject>

#include "encryption_exports.h"

class Chat;
class EncryptionProvider;
class RawMessage;

class ENCRYPTIONAPI Decryptor : public QObject
{
	Q_OBJECT

	EncryptionProvider *Provider;

public:
	explicit Decryptor(EncryptionProvider *provider, QObject *parent = 0);
	virtual ~Decryptor() {}

	EncryptionProvider * provider() { return Provider; }

	virtual RawMessage decrypt(const RawMessage &rawMessage, Chat chat, bool *ok = 0) = 0;

};

#endif // DECRYPTOR_H
